@@ -16,14 +16,11 @@ class CoopBarNode(template.Node):
     def render(self, context):
         request = context.get("request", None)
         commands = CoopBar().get_commands(request, context)
-        if commands: #hide admin-bar if nothing to display
+        if commands:  # hide admin-bar if nothing to display
             css_classes = CoopBar().get_css_classes(request, context)
             context_dict = {'commands': commands, 'css_classes': css_classes}
-            #for var_name in ('article', 'object'):
-            #    var = context.get(var_name, None)
-            #    context_dict[var_name] = var
-            t = get_template("coop_bar.html")
-            return t.render(Context(context_dict))
+            the_template = get_template("coop_bar.html")
+            return the_template.render(Context(context_dict))
         return u''
 
 @register.tag
